@@ -1,4 +1,4 @@
-# Time-stamp: <2013-09-11 17:39:20 Tao Liu>
+# Time-stamp: <2014-06-16 13:15:59 Tao Liu>
 
 """Description: MACS 2 main executable
 
@@ -6,7 +6,7 @@ Copyright (c) 2008,2009 Yong Zhang, Tao Liu <taoliu@jimmy.harvard.edu>
 Copyright (c) 2010,2011 Tao Liu <taoliu@jimmy.harvard.edu>
 
 This code is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License (see the file COPYING included
+under the terms of the BSD License (see the file COPYING included
 with the distribution).
 
 @status: release candidate
@@ -19,6 +19,7 @@ with the distribution).
 # python modules
 # ------------------------------------
 
+import os
 import sys
 import logging
 from time import strftime
@@ -157,10 +158,14 @@ def run( args ):
     if options.nomodel:
         info("#2 Skipped...")
         if options.PE_MODE:
-            options.shiftsize = 0
+            #options.shiftsize = 0
             options.d = options.tsize
         else:
-            options.d=options.shiftsize*2
+            options.d=options.extsize
+        if options.shift > 0:
+            info("#2 Sequencing ends will be shifted towards 3' by %d bp(s)" % (options.shift))
+        elif options.shift < 0:
+            info("#2 Sequencing ends will be shifted towards 5' by %d bp(s)" % (options.shift * -1))
         info("#2 Use %d as fragment length" % (options.d))
         options.scanwindow=2*options.d  # remove the effect of --bw
     else:
@@ -183,21 +188,20 @@ def run( args ):
             if options.d <= 2*options.tsize:
                 warn("#2 Since the d (%.0f) calculated from paired-peaks are smaller than 2*tag length, it may be influenced by unknown sequencing problem!" % (options.d))
                 if options.onauto:
-                    options.d=options.shiftsize*2
+                    options.d=options.extsize
                     options.scanwindow=2*options.d 
-                    warn("#2 MACS will use %d as shiftsize, %d as fragment length. NOTE: if the d calculated is still acceptable, please do not use --fix-bimodal option!" % (options.shiftsize,options.d))
+                    warn("#2 MACS will use %d as EXTSIZE/fragment length d. NOTE: if the d calculated is still acceptable, please do not use --fix-bimodal option!" % (options.d))
                 else:
                     warn("#2 You may need to consider one of the other alternative d(s): %s" %  ','.join(map(str,peakmodel.alternative_d)))
-                    warn("#2 You can restart the process with --nomodel --shiftsize XXX with your choice or an arbitrary number. Nontheless, MACS will continute computing.")
+                    warn("#2 You can restart the process with --nomodel --extsize XXX with your choice or an arbitrary number. Nontheless, MACS will continute computing.")
                 
         except NotEnoughPairsException:
             if not options.onauto:
                 sys.exit(1)
             warn("#2 Skipped...")
-            options.d=options.shiftsize*2
+            options.d=options.extsize
             options.scanwindow=2*options.d 
-            warn("#2 Since --fix-bimodal is set, MACS will use %d as shiftsize, %d as fragment length" % (options.shiftsize,options.d))
-
+            warn("#2 Since --fix-bimodal is set, MACS will use %d as fragment length" % (options.d))
 
     #3 Call Peaks
     info("#3 Call peaks...")
@@ -205,6 +209,9 @@ def run( args ):
         info("# local lambda is disabled!")
 
     # decide options.tocontrol according to options.tolarge
+    if control and options.PE_MODE:
+        c1 = c1 * 2
+    
     if control:
         if options.downsample:
             # use random sampling to balance treatment and control
@@ -269,12 +276,17 @@ def run( args ):
     #4 output
     #4.1 peaks in XLS
     info("#4 Write output xls file... %s" % (options.peakxls))
-    ofhd_xls = open(options.peakxls,"w")
+    ofhd_xls = open( options.peakxls, "w" )
     ofhd_xls.write("# This file is generated by MACS version %s\n" % (MACS_VERSION))
     ofhd_xls.write(options.argtxt+"\n")
 
     ofhd_xls.write(tagsinfo)
 
+    if options.shift > 0:
+        ofhd_xls.write("#2 Sequencing ends will be shifted towards 3' by %d bp(s)\n" % (options.shift))
+    elif options.shift < 0:
+        ofhd_xls.write("#2 Sequencing ends will be shifted towards 5' by %d bp(s)\n" % (options.shift * -1))
+
     ofhd_xls.write("# d = %d\n" % (options.d))
     try:
         ofhd_xls.write("# alternative fragment length(s) may be %s bps\n" % ','.join(map(str,peakmodel.alternative_d)))
@@ -298,12 +310,12 @@ def run( args ):
         #peakdetect.peaks.write_to_bed (ofhd_bed, name_prefix="%s_peak_", name = options.name, description="Peaks for %s (Made with MACS v2, " + strftime("%x") + ")", score_column=score_column, trackline=options.trackline)
         #ofhd_bed.close()
         info("#4 Write peak in narrowPeak format file... %s" % (options.peakNarrowPeak))
-        ofhd_bed = open(options.peakNarrowPeak,"w")
+        ofhd_bed = open( options.peakNarrowPeak, "w" )
         peakdetect.peaks.write_to_narrowPeak (ofhd_bed, name_prefix="%s_peak_", name=options.name, score_column=score_column, trackline=options.trackline )
         ofhd_bed.close()
         #4.2-2 summits in BED
         info("#4 Write summits bed file... %s" % (options.summitbed))
-        ofhd_summits = open(options.summitbed,"w")
+        ofhd_summits = open( options.summitbed, "w" )
         peakdetect.peaks.write_to_summit_bed (ofhd_summits, name_prefix="%s_peak_", name=options.name,
                                               description="Summits for %s (Made with MACS v2, " + strftime("%x") + ")",
                                               score_column=score_column, trackline=options.trackline )
@@ -311,11 +323,11 @@ def run( args ):
     #4.2 broad peaks in bed12 or gappedPeak
     else:
         info("#4 Write broad peak in broadPeak format file... %s" % (options.peakBroadPeak))
-        ofhd_bed = open(options.peakBroadPeak,"w")
+        ofhd_bed = open( options.peakBroadPeak, "w" )
         peakdetect.peaks.write_to_broadPeak (ofhd_bed, name_prefix="%s_peak_", name=options.name, description=options.name, trackline=options.trackline)
         ofhd_bed.close()
         info("#4 Write broad peak in bed12/gappedPeak format file... %s" % (options.peakGappedPeak))
-        ofhd_bed = open(options.peakGappedPeak,"w")
+        ofhd_bed = open( options.peakGappedPeak, "w" )
         peakdetect.peaks.write_to_gappedPeak (ofhd_bed, name_prefix="%s_peak_", name=options.name, description=options.name, trackline=options.trackline)
         ofhd_bed.close()
 
