@@ -1,4 +1,4 @@
-# Time-stamp: <2013-09-11 22:44:34 Tao Liu>
+# Time-stamp: <2014-02-24 11:35:25 Tao Liu>
 
 """Description: MACS 2 main executable
 
@@ -6,7 +6,7 @@ Copyright (c) 2008,2009 Yong Zhang, Tao Liu <taoliu@jimmy.harvard.edu>
 Copyright (c) 2010,2011 Tao Liu <taoliu@jimmy.harvard.edu>
 
 This code is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License (see the file COPYING included
+under the terms of the BSD License (see the file COPYING included
 with the distribution).
 
 @status: release candidate
@@ -19,6 +19,7 @@ with the distribution).
 # python modules
 # ------------------------------------
 
+import os
 import sys
 import logging
 from time import strftime
@@ -27,7 +28,7 @@ from time import strftime
 # own python modules
 # ------------------------------------
 from MACS2.IO import cBedGraphIO
-from MACS2.IO.cScoreTrack import DiffScoreTrackI
+from MACS2.IO.cDiffScore import DiffScoreTrackI
 from MACS2.IO.cPeakIO import PeakIO
 from MACS2.OptValidator import diff_opt_validate
 from MACS2.OutputWriter import *
@@ -147,10 +148,10 @@ def run( args ):
 #    diffscore.print_diff_peaks()
     
     info("Write output xls and BED files...")
-    ofhd_xls = open(options.peakxls,"w")
+    ofhd_xls = open( os.path.join( options.outdir, options.peakxls), "w" )
     ofhd_xls.write("# This file is generated by MACS version, using the diffpeak module %s\n" % (MACS_VERSION))
-    ofhd_xls.write(options.argtxt+"\n")
-    ofhd_bed = open(options.peakbed,"w")
+    ofhd_xls.write( options.argtxt+"\n" )
+    ofhd_bed = open( os.path.join( options.outdir, options.peakbed), "w" )
 
     # pass write method so we can print too, and include name
     diffscore.write_peaks(xls=ofhd_xls, bed=ofhd_bed,
@@ -162,10 +163,10 @@ def run( args ):
     
     if diffscore.has_peakio():
         info("Write annotated peak xls files...")
-        ofhd_xls1 = open(options.peak1xls,"w")
+        ofhd_xls1 = open( os.path.join( options.outdir, options.peak1xls), "w" )
         ofhd_xls1.write("# This file is generated by MACS version, using the diffpeak module %s\n" % (MACS_VERSION))
         ofhd_xls1.write(options.argtxt+"\n")
-        ofhd_xls2 = open(options.peak2xls,"w")
+        ofhd_xls2 = open( os.path.join( options.outdir, options.peak2xls), "w" )
         ofhd_xls2.write("# This file is generated by MACS version, using the diffpeak module %s\n" % (MACS_VERSION))
         ofhd_xls2.write(options.argtxt+"\n")
         diffscore.write_peaks_by_summit(ofhd_xls1, ofhd_xls2,
@@ -175,9 +176,9 @@ def run( args ):
     
     if options.store_bdg:
         info("#4 Write output bedgraph files...")
-        ofhd_logLR = open(options.bdglogLR,"w")
-        ofhd_pvalue = open(options.bdgpvalue,"w")
-        ofhd_logFC = open(options.bdglogFC,"w")
+        ofhd_logLR = open( os.path.join( options.outdir, options.bdglogLR), "w" )
+        ofhd_pvalue = open( os.path.join( options.outdir, options.bdgpvalue), "w" )
+        ofhd_logFC = open( os.path.join( options.outdir, options.bdglogFC), "w" )
         diffscore.write_bedgraphs(logLR=ofhd_logLR, pvalue=ofhd_pvalue,
                                   logFC=ofhd_logFC, name = options.name,
                                   description=" for %s (Made with MACS v2, " + strftime("%x") + ")",
