@@ -1,11 +1,11 @@
-# Time-stamp: <2012-10-03 12:18:11 Tao Liu>
+# Time-stamp: <2014-06-17 00:42:04 Tao Liu>
 
 """Description: Filter duplicate reads depending on sequencing depth.
 
 Copyright (c) 2011 Tao Liu <taoliu@jimmy.harvard.edu>
 
 This code is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License (see the file COPYING included
+under the terms of the BSD License (see the file COPYING included
 with the distribution).
 
 @status: release candidate
@@ -44,8 +44,7 @@ def run( o_options ):
     error = options.error
 
     if options.outputfile != "stdout":
-        assert not os.path.exists(options.outputfile), "%s already exists, please check!" % options.outputfile
-        outfhd = open(options.outputfile,"w")
+        outfhd = open( os.path.join( options.outdir, options.outputfile ) ,"w" )
     else:
         outfhd = sys.stdout
     
@@ -69,13 +68,22 @@ def run( o_options ):
             max_dup_tags = int(options.keepduplicates)
             info("filter out redundant tags at the same location and the same strand by allowing at most %d tag(s)" % (max_dup_tags))
 
-        fwtrack = fwtrack.filter_dup(max_dup_tags)
-        t1 = fwtrack.total
+        if not options.dryrun:
+            fwtrack = fwtrack.filter_dup(max_dup_tags)
+            t1 = fwtrack.total
+        else:
+            t1 = fwtrack.filter_dup_dryrun( max_dup_tags )
+
         info(" tags after filtering in alignment file: %d" % (t1))
         info(" Redundant rate of alignment file: %.2f" % (float(t0-t1)/t0))
-    info("Write to BED file")
-    fwtrack.print_to_bed(fhd=outfhd)
-    info("finished! Check %s." % options.outputfile)
+            
+            
+    if not options.dryrun:
+        info( "Write to BED file" )
+        fwtrack.print_to_bed( fhd=outfhd )
+        info( "finished! Check %s." % options.outputfile )
+    else:
+        info( "Dry-run is finished!" )
 
 def cal_max_dup_tags ( genome_size, tags_number, p=1e-5 ):
     """Calculate the maximum duplicated tag number based on genome
