@@ -1,11 +1,11 @@
-# Time-stamp: <2013-04-15 14:08:12 Tao Liu>
+# Time-stamp: <2013-10-28 01:40:58 Tao Liu>
 
 """Description: Random sample certain number/percentage of tags.
 
 Copyright (c) 2011 Tao Liu <taoliu@jimmy.harvard.edu>
 
 This code is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License (see the file COPYING included
+under the terms of the BSD License (see the file COPYING included
 with the distribution).
 
 @status: release candidate
@@ -40,8 +40,7 @@ def run( options0 ):
     error = options.error
     #0 check output file
     if options.outputfile:
-        assert not os.path.exists(options.outputfile), "%s already exists, please check!" % options.outputfile
-        outfhd = open(options.outputfile,"w")
+        outfhd = open( os.path.join( options.outdir, options.outputfile ), "w" )
     else:
         outfhd = sys.stdout
     
